"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RunSummaries = void 0;
// @ts-ignore
const codecatalyst_adk_core_1 = require("@aws/codecatalyst-adk-core");
const constants_1 = require("./constants");
const ACTION_RUN_SUMMARY = 'ACTION_RUN_SUMMARY';
const MAX_RUN_SUMMARY_TEXT_LENGTH = 200;
/**
 * Use the RunSummaries construct to set custom summary messages during the execution of actions that will be surfaced on the workflows UI.
 */
class RunSummaries {
    static addRunSummary(text, summaryLevel) {
        const runSummaryMessage = {
            text: constants_1.CUSTOM_STATUS_CODE,
            message: JSON.stringify(this.truncate(text.toString(), MAX_RUN_SUMMARY_TEXT_LENGTH)),
            level: summaryLevel,
        };
        this.runSummaries.push(runSummaryMessage);
        (0, codecatalyst_adk_core_1.setOutput)(ACTION_RUN_SUMMARY, JSON.stringify(this.runSummaries));
    }
    static addRunSummaryMessage(message) {
        const runSummaryMessage = {
            text: message.statusCode,
            level: message.level,
            message: message.text !== undefined ?
                JSON.stringify(this.truncate(message.text.toString(), MAX_RUN_SUMMARY_TEXT_LENGTH)) :
                message.text,
            templateVariables: message.templateVariables,
        };
        this.runSummaries.push(runSummaryMessage);
        (0, codecatalyst_adk_core_1.setOutput)(ACTION_RUN_SUMMARY, JSON.stringify(this.runSummaries));
    }
    static clearRunSummaries() {
        this.runSummaries = [];
        (0, codecatalyst_adk_core_1.setOutput)(ACTION_RUN_SUMMARY, JSON.stringify(this.runSummaries));
    }
    static truncate(s, length) {
        if (s.length < length) {
            return s;
        }
        return `${s.substring(0, length)}...`;
    }
}
exports.RunSummaries = RunSummaries;
RunSummaries.runSummaries = [];
